@@ -5,6 +5,7 @@ require Exporter;
 @EXPORT = qw(run_tests list_dynamic list_static);
 
 use strict;
+use warnings;
 use File::Path;
 use MakeMaker::Test::Utils;
 use Config;
@@ -19,7 +20,8 @@ use ExtUtils::MM;
 my $tempdir = tempdir(DIR => getcwd, CLEANUP => 1);
 chdir $tempdir;
 my $typemap = 'type map';
-$typemap =~ s/ //g unless MM->new({NAME=>'name', NORECURS=>1})->can_dep_space;
+my $MM = MM->new({NAME=>'name', NORECURS=>1});
+$typemap =~ s/ //g unless $MM->can_dep_space;
 chdir File::Spec->updir;
 
 my $PM_TEST = <<'END';
@@ -133,7 +135,7 @@ my %Files = (
   'Makefile.PL' => sprintf($MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{'$typemap'}, ''),
 );
 
-my %label2files = (basic => \%Files);
+my %label2files = (basic => \%Files, basic2 => \%Files); # basic2 so no clash
 
 $label2files{bscode} = +{
   %{ $label2files{'basic'} }, # make copy
@@ -148,6 +150,11 @@ $label2files{static} = +{
     $MAKEFILEPL, 'Test', 'lib/XS/Test.pm', qq{'$typemap'},
     q{LINKTYPE => 'static'},
   ),
+  "blib/arch/auto/share/dist/x-y/libwhatevs$MM->{LIB_EXT}" => 'hi there', # mimic what File::ShareDir can do
+  "blib/arch/auto/Alien/ROOT/root/lib/root/root$MM->{LIB_EXT}" => 'hi there', # mimic Alien::ROOT that installs a .a without extralibs.ld
+  # next two mimic dist that installs a .a WITH extralibs.ld but that is still not XS
+  "blib/arch/auto/Dist/File$MM->{LIB_EXT}" => 'hi there',
+  "blib/arch/auto/Dist/extralibs.ld" => '',
 };
 
 $label2files{subdirs} = +{
@@ -211,6 +218,71 @@ $label2files{subdirsstatic} = +{
   ),
 };
 
+# to mimic behaviour of CGI-Deurl-XS version 0.08
+my $OTHERMAKEFILE = File::Spec->catfile('Other', makefile_name());
+$label2files{subdirsskip} = +{
+  %{ $label2files{subdirscomplex} }, # make copy
+  'Makefile.PL' => sprintf(
+    $MAKEFILEPL,
+    'Test', 'Test.pm', qq{},
+    q[
+MYEXTLIB => '] . File::Spec->catfile('Other', 'libparser$(LIB_EXT)') . q[',
+     ]
+  )
+  . q[
+sub MY::postamble {
+    my ($self) = @_;
+    return '$(MYEXTLIB) : ] . $OTHERMAKEFILE . q['."\n\t".$self->cd('Other', '$(MAKE) $(PASSTHRU)')."\n";
+}
+     ],
+  'Other/Makefile.PL' => sprintf(
+    $MAKEFILEPL,
+    'Other', 'Other.pm', qq{},
+    <<'EOF',
+SKIP   => [qw(all static dynamic )],
+clean  => {'FILES' => 'libparser$(LIB_EXT)'},
+EOF
+  ) . <<'EOF',
+sub MY::top_targets {
+  my ($self) = @_;
+  my $static_lib_pure_cmd = $self->static_lib_pure_cmd('$(O_FILES)');
+  <<'SNIP' . $static_lib_pure_cmd;
+all :: static
+
+pure_all :: static
+
+static :: libparser$(LIB_EXT)
+
+libparser$(LIB_EXT): $(O_FILES)
+SNIP
+}
+EOF
+  't/plus1.t' => <<'END',
+#!/usr/bin/perl -w
+use Test::More tests => 2;
+use_ok "XS::Test";
+is XS::Test::plus1(3), 4;
+END
+  'Test.xs' => <<EOF,
+#ifdef __cplusplus
+extern "C" {
+#endif
+int plus1(int);
+#ifdef __cplusplus
+}
+#endif
+$XS_TEST
+int
+plus1(input)
+       int     input
+   CODE:
+       RETVAL = plus1(input);
+   OUTPUT:
+       RETVAL
+EOF
+};
+virtual_rename('subdirsskip', 'Other/lib/file.c', 'Other/file.c');
+
 my $XS_MULTI = $XS_OTHER;
 # check compiling from top dir still can include local
 $XS_MULTI =~ s:(#include "XSUB.h"):$1\n#include "header.h":;
@@ -310,7 +382,7 @@ sub setup_xs {
 
 sub list_static {
   (
-    ( !$Config{usedl} ? [ 'basic', '', '' ] : ()), # still needs testing on static perl
+    ( !$Config{usedl} ? [ 'basic2', '', '' ] : ()), # still needs testing on static perl
     [ 'static', '', '' ],
     [ 'basic', ' static', '_static' ],
     [ 'multi', ' static', '_static' ],
@@ -326,15 +398,22 @@ sub list_dynamic {
     $^O ne 'MSWin32' ? (
         [ 'bscode', '', '' ],
         [ 'bscodemulti', '', '' ],
-        [ 'subdirscomplex', '', '' ],
+        $^O !~ m!^(VMS|aix)$! ? ([ 'subdirscomplex', '', '' ]) : (),
     ) : (), # DynaLoader different
     [ 'subdirs', '', '' ],
-    [ 'subdirsstatic', ' LINKTYPE=dynamic', ' LINKTYPE=dynamic' ],
-    [ 'subdirsstatic', ' dynamic', '_dynamic' ],
+    # https://github.com/Perl/perl5/issues/17601
+    # https://rt.cpan.org/Ticket/Display.html?id=115321
+    $^O ne 'MSWin32' ? (
+        [ 'subdirsstatic', ' LINKTYPE=dynamic', ' LINKTYPE=dynamic' ],
+        [ 'subdirsstatic', ' dynamic', '_dynamic' ],
+    ) : (),
     [ 'multi', '', '' ],
-    [ 'staticmulti', ' LINKTYPE=dynamic', ' LINKTYPE=dynamic' ],
-    [ 'staticmulti', ' dynamic', '_dynamic' ],
+    $^O ne 'MSWin32' ? (
+        [ 'staticmulti', ' LINKTYPE=dynamic', ' LINKTYPE=dynamic' ],
+        [ 'staticmulti', ' dynamic', '_dynamic' ],
+    ) : (),
     [ 'xsbuild', '', '' ],
+    [ 'subdirsskip', '', '' ],
   );
 }
 
@@ -391,7 +470,11 @@ sub run_tests {
   }
 
   chdir File::Spec->updir or die;
-  ok rmtree($dir), "teardown $dir";
+  if ($ENV{EUMM_KEEP_TESTDIRS}) {
+    ok 1, "don't teardown $dir";
+  } else {
+    ok rmtree($dir), "teardown $dir";
+  }
 }
 
 1;
