@@ -11,11 +11,11 @@ TAP::Parser::Iterator::Stream - Iterator for filehandle-based TAP sources
 
 =head1 VERSION
 
-Version 3.39
+Version 3.44
 
 =cut
 
-our $VERSION = '3.39';
+our $VERSION = '3.44';
 
 =head1 SYNOPSIS
 
@@ -90,6 +90,16 @@ sub _finish {
     close delete $self->{fh};
 }
 
+sub get_select_handles {
+    my $self = shift;
+
+    # return our handle in case it's a socket or pipe (select()-able)
+    return ( $self->{fh}, )
+        if (-S $self->{fh} || -p $self->{fh});
+
+    return;
+}
+
 1;
 
 =head1 ATTRIBUTION
